#ifdef CL_SUCCESS
const_iv(SUCCESS)
#endif
#ifdef CL_DEVICE_NOT_FOUND
const_iv(DEVICE_NOT_FOUND)
#endif
#ifdef CL_DEVICE_NOT_AVAILABLE
const_iv(DEVICE_NOT_AVAILABLE)
#endif
#ifdef CL_COMPILER_NOT_AVAILABLE
const_iv(COMPILER_NOT_AVAILABLE)
#endif
#ifdef CL_MEM_OBJECT_ALLOCATION_FAILURE
const_iv(MEM_OBJECT_ALLOCATION_FAILURE)
#endif
#ifdef CL_OUT_OF_RESOURCES
const_iv(OUT_OF_RESOURCES)
#endif
#ifdef CL_OUT_OF_HOST_MEMORY
const_iv(OUT_OF_HOST_MEMORY)
#endif
#ifdef CL_PROFILING_INFO_NOT_AVAILABLE
const_iv(PROFILING_INFO_NOT_AVAILABLE)
#endif
#ifdef CL_MEM_COPY_OVERLAP
const_iv(MEM_COPY_OVERLAP)
#endif
#ifdef CL_IMAGE_FORMAT_MISMATCH
const_iv(IMAGE_FORMAT_MISMATCH)
#endif
#ifdef CL_IMAGE_FORMAT_NOT_SUPPORTED
const_iv(IMAGE_FORMAT_NOT_SUPPORTED)
#endif
#ifdef CL_BUILD_PROGRAM_FAILURE
const_iv(BUILD_PROGRAM_FAILURE)
#endif
#ifdef CL_MAP_FAILURE
const_iv(MAP_FAILURE)
#endif
#ifdef CL_MISALIGNED_SUB_BUFFER_OFFSET
const_iv(MISALIGNED_SUB_BUFFER_OFFSET)
#endif
#ifdef CL_EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST
const_iv(EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)
#endif
#ifdef CL_COMPILE_PROGRAM_FAILURE
const_iv(COMPILE_PROGRAM_FAILURE)
#endif
#ifdef CL_LINKER_NOT_AVAILABLE
const_iv(LINKER_NOT_AVAILABLE)
#endif
#ifdef CL_LINK_PROGRAM_FAILURE
const_iv(LINK_PROGRAM_FAILURE)
#endif
#ifdef CL_DEVICE_PARTITION_FAILED
const_iv(DEVICE_PARTITION_FAILED)
#endif
#ifdef CL_KERNEL_ARG_INFO_NOT_AVAILABLE
const_iv(KERNEL_ARG_INFO_NOT_AVAILABLE)
#endif
#ifdef CL_INVALID_VALUE
const_iv(INVALID_VALUE)
#endif
#ifdef CL_INVALID_DEVICE_TYPE
const_iv(INVALID_DEVICE_TYPE)
#endif
#ifdef CL_INVALID_PLATFORM
const_iv(INVALID_PLATFORM)
#endif
#ifdef CL_INVALID_DEVICE
const_iv(INVALID_DEVICE)
#endif
#ifdef CL_INVALID_CONTEXT
const_iv(INVALID_CONTEXT)
#endif
#ifdef CL_INVALID_QUEUE_PROPERTIES
const_iv(INVALID_QUEUE_PROPERTIES)
#endif
#ifdef CL_INVALID_COMMAND_QUEUE
const_iv(INVALID_COMMAND_QUEUE)
#endif
#ifdef CL_INVALID_HOST_PTR
const_iv(INVALID_HOST_PTR)
#endif
#ifdef CL_INVALID_MEM_OBJECT
const_iv(INVALID_MEM_OBJECT)
#endif
#ifdef CL_INVALID_IMAGE_FORMAT_DESCRIPTOR
const_iv(INVALID_IMAGE_FORMAT_DESCRIPTOR)
#endif
#ifdef CL_INVALID_IMAGE_SIZE
const_iv(INVALID_IMAGE_SIZE)
#endif
#ifdef CL_INVALID_SAMPLER
const_iv(INVALID_SAMPLER)
#endif
#ifdef CL_INVALID_BINARY
const_iv(INVALID_BINARY)
#endif
#ifdef CL_INVALID_BUILD_OPTIONS
const_iv(INVALID_BUILD_OPTIONS)
#endif
#ifdef CL_INVALID_PROGRAM
const_iv(INVALID_PROGRAM)
#endif
#ifdef CL_INVALID_PROGRAM_EXECUTABLE
const_iv(INVALID_PROGRAM_EXECUTABLE)
#endif
#ifdef CL_INVALID_KERNEL_NAME
const_iv(INVALID_KERNEL_NAME)
#endif
#ifdef CL_INVALID_KERNEL_DEFINITION
const_iv(INVALID_KERNEL_DEFINITION)
#endif
#ifdef CL_INVALID_KERNEL
const_iv(INVALID_KERNEL)
#endif
#ifdef CL_INVALID_ARG_INDEX
const_iv(INVALID_ARG_INDEX)
#endif
#ifdef CL_INVALID_ARG_VALUE
const_iv(INVALID_ARG_VALUE)
#endif
#ifdef CL_INVALID_ARG_SIZE
const_iv(INVALID_ARG_SIZE)
#endif
#ifdef CL_INVALID_KERNEL_ARGS
const_iv(INVALID_KERNEL_ARGS)
#endif
#ifdef CL_INVALID_WORK_DIMENSION
const_iv(INVALID_WORK_DIMENSION)
#endif
#ifdef CL_INVALID_WORK_GROUP_SIZE
const_iv(INVALID_WORK_GROUP_SIZE)
#endif
#ifdef CL_INVALID_WORK_ITEM_SIZE
const_iv(INVALID_WORK_ITEM_SIZE)
#endif
#ifdef CL_INVALID_GLOBAL_OFFSET
const_iv(INVALID_GLOBAL_OFFSET)
#endif
#ifdef CL_INVALID_EVENT_WAIT_LIST
const_iv(INVALID_EVENT_WAIT_LIST)
#endif
#ifdef CL_INVALID_EVENT
const_iv(INVALID_EVENT)
#endif
#ifdef CL_INVALID_OPERATION
const_iv(INVALID_OPERATION)
#endif
#ifdef CL_INVALID_GL_OBJECT
const_iv(INVALID_GL_OBJECT)
#endif
#ifdef CL_INVALID_BUFFER_SIZE
const_iv(INVALID_BUFFER_SIZE)
#endif
#ifdef CL_INVALID_MIP_LEVEL
const_iv(INVALID_MIP_LEVEL)
#endif
#ifdef CL_INVALID_GLOBAL_WORK_SIZE
const_iv(INVALID_GLOBAL_WORK_SIZE)
#endif
#ifdef CL_INVALID_PROPERTY
const_iv(INVALID_PROPERTY)
#endif
#ifdef CL_INVALID_IMAGE_DESCRIPTOR
const_iv(INVALID_IMAGE_DESCRIPTOR)
#endif
#ifdef CL_INVALID_COMPILER_OPTIONS
const_iv(INVALID_COMPILER_OPTIONS)
#endif
#ifdef CL_INVALID_LINKER_OPTIONS
const_iv(INVALID_LINKER_OPTIONS)
#endif
#ifdef CL_INVALID_DEVICE_PARTITION_COUNT
const_iv(INVALID_DEVICE_PARTITION_COUNT)
#endif
#ifdef CL_VERSION_1_0
const_iv(VERSION_1_0)
#endif
#ifdef CL_VERSION_1_1
const_iv(VERSION_1_1)
#endif
#ifdef CL_VERSION_1_2
const_iv(VERSION_1_2)
#endif
#ifdef CL_FALSE
const_iv(FALSE)
#endif
#ifdef CL_TRUE
const_iv(TRUE)
#endif
#ifdef CL_BLOCKING
const_iv(BLOCKING)
#endif
#ifdef CL_NON_BLOCKING
const_iv(NON_BLOCKING)
#endif
#ifdef CL_PLATFORM_PROFILE
const_iv(PLATFORM_PROFILE)
#endif
#ifdef CL_PLATFORM_VERSION
const_iv(PLATFORM_VERSION)
#endif
#ifdef CL_PLATFORM_NAME
const_iv(PLATFORM_NAME)
#endif
#ifdef CL_PLATFORM_VENDOR
const_iv(PLATFORM_VENDOR)
#endif
#ifdef CL_PLATFORM_EXTENSIONS
const_iv(PLATFORM_EXTENSIONS)
#endif
#ifdef CL_DEVICE_TYPE_DEFAULT
const_iv(DEVICE_TYPE_DEFAULT)
#endif
#ifdef CL_DEVICE_TYPE_CPU
const_iv(DEVICE_TYPE_CPU)
#endif
#ifdef CL_DEVICE_TYPE_GPU
const_iv(DEVICE_TYPE_GPU)
#endif
#ifdef CL_DEVICE_TYPE_ACCELERATOR
const_iv(DEVICE_TYPE_ACCELERATOR)
#endif
#ifdef CL_DEVICE_TYPE_CUSTOM
const_iv(DEVICE_TYPE_CUSTOM)
#endif
#ifdef CL_DEVICE_TYPE_ALL
const_iv(DEVICE_TYPE_ALL)
#endif
#ifdef CL_DEVICE_TYPE
const_iv(DEVICE_TYPE)
#endif
#ifdef CL_DEVICE_VENDOR_ID
const_iv(DEVICE_VENDOR_ID)
#endif
#ifdef CL_DEVICE_MAX_COMPUTE_UNITS
const_iv(DEVICE_MAX_COMPUTE_UNITS)
#endif
#ifdef CL_DEVICE_MAX_WORK_ITEM_DIMENSIONS
const_iv(DEVICE_MAX_WORK_ITEM_DIMENSIONS)
#endif
#ifdef CL_DEVICE_MAX_WORK_GROUP_SIZE
const_iv(DEVICE_MAX_WORK_GROUP_SIZE)
#endif
#ifdef CL_DEVICE_MAX_WORK_ITEM_SIZES
const_iv(DEVICE_MAX_WORK_ITEM_SIZES)
#endif
#ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_CHAR
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_CHAR)
#endif
#ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_SHORT
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_SHORT)
#endif
#ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_INT
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_INT)
#endif
#ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_LONG
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_LONG)
#endif
#ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_FLOAT
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_FLOAT)
#endif
#ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_DOUBLE
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_DOUBLE)
#endif
#ifdef CL_DEVICE_MAX_CLOCK_FREQUENCY
const_iv(DEVICE_MAX_CLOCK_FREQUENCY)
#endif
#ifdef CL_DEVICE_ADDRESS_BITS
const_iv(DEVICE_ADDRESS_BITS)
#endif
#ifdef CL_DEVICE_MAX_READ_IMAGE_ARGS
const_iv(DEVICE_MAX_READ_IMAGE_ARGS)
#endif
#ifdef CL_DEVICE_MAX_WRITE_IMAGE_ARGS
const_iv(DEVICE_MAX_WRITE_IMAGE_ARGS)
#endif
#ifdef CL_DEVICE_MAX_MEM_ALLOC_SIZE
const_iv(DEVICE_MAX_MEM_ALLOC_SIZE)
#endif
#ifdef CL_DEVICE_IMAGE2D_MAX_WIDTH
const_iv(DEVICE_IMAGE2D_MAX_WIDTH)
#endif
#ifdef CL_DEVICE_IMAGE2D_MAX_HEIGHT
const_iv(DEVICE_IMAGE2D_MAX_HEIGHT)
#endif
#ifdef CL_DEVICE_IMAGE3D_MAX_WIDTH
const_iv(DEVICE_IMAGE3D_MAX_WIDTH)
#endif
#ifdef CL_DEVICE_IMAGE3D_MAX_HEIGHT
const_iv(DEVICE_IMAGE3D_MAX_HEIGHT)
#endif
#ifdef CL_DEVICE_IMAGE3D_MAX_DEPTH
const_iv(DEVICE_IMAGE3D_MAX_DEPTH)
#endif
#ifdef CL_DEVICE_IMAGE_SUPPORT
const_iv(DEVICE_IMAGE_SUPPORT)
#endif
#ifdef CL_DEVICE_MAX_PARAMETER_SIZE
const_iv(DEVICE_MAX_PARAMETER_SIZE)
#endif
#ifdef CL_DEVICE_MAX_SAMPLERS
const_iv(DEVICE_MAX_SAMPLERS)
#endif
#ifdef CL_DEVICE_MEM_BASE_ADDR_ALIGN
const_iv(DEVICE_MEM_BASE_ADDR_ALIGN)
#endif
#ifdef CL_DEVICE_MIN_DATA_TYPE_ALIGN_SIZE
const_iv(DEVICE_MIN_DATA_TYPE_ALIGN_SIZE)
#endif
#ifdef CL_DEVICE_SINGLE_FP_CONFIG
const_iv(DEVICE_SINGLE_FP_CONFIG)
#endif
#ifdef CL_DEVICE_GLOBAL_MEM_CACHE_TYPE
const_iv(DEVICE_GLOBAL_MEM_CACHE_TYPE)
#endif
#ifdef CL_DEVICE_GLOBAL_MEM_CACHELINE_SIZE
const_iv(DEVICE_GLOBAL_MEM_CACHELINE_SIZE)
#endif
#ifdef CL_DEVICE_GLOBAL_MEM_CACHE_SIZE
const_iv(DEVICE_GLOBAL_MEM_CACHE_SIZE)
#endif
#ifdef CL_DEVICE_GLOBAL_MEM_SIZE
const_iv(DEVICE_GLOBAL_MEM_SIZE)
#endif
#ifdef CL_DEVICE_MAX_CONSTANT_BUFFER_SIZE
const_iv(DEVICE_MAX_CONSTANT_BUFFER_SIZE)
#endif
#ifdef CL_DEVICE_MAX_CONSTANT_ARGS
const_iv(DEVICE_MAX_CONSTANT_ARGS)
#endif
#ifdef CL_DEVICE_LOCAL_MEM_TYPE
const_iv(DEVICE_LOCAL_MEM_TYPE)
#endif
#ifdef CL_DEVICE_LOCAL_MEM_SIZE
const_iv(DEVICE_LOCAL_MEM_SIZE)
#endif
#ifdef CL_DEVICE_ERROR_CORRECTION_SUPPORT
const_iv(DEVICE_ERROR_CORRECTION_SUPPORT)
#endif
#ifdef CL_DEVICE_PROFILING_TIMER_RESOLUTION
const_iv(DEVICE_PROFILING_TIMER_RESOLUTION)
#endif
#ifdef CL_DEVICE_ENDIAN_LITTLE
const_iv(DEVICE_ENDIAN_LITTLE)
#endif
#ifdef CL_DEVICE_AVAILABLE
const_iv(DEVICE_AVAILABLE)
#endif
#ifdef CL_DEVICE_COMPILER_AVAILABLE
const_iv(DEVICE_COMPILER_AVAILABLE)
#endif
#ifdef CL_DEVICE_EXECUTION_CAPABILITIES
const_iv(DEVICE_EXECUTION_CAPABILITIES)
#endif
#ifdef CL_DEVICE_QUEUE_PROPERTIES
const_iv(DEVICE_QUEUE_PROPERTIES)
#endif
#ifdef CL_DEVICE_NAME
const_iv(DEVICE_NAME)
#endif
#ifdef CL_DEVICE_VENDOR
const_iv(DEVICE_VENDOR)
#endif
#ifdef CL_DRIVER_VERSION
const_iv(DRIVER_VERSION)
#endif
#ifdef CL_DEVICE_PROFILE
const_iv(DEVICE_PROFILE)
#endif
#ifdef CL_DEVICE_VERSION
const_iv(DEVICE_VERSION)
#endif
#ifdef CL_DEVICE_EXTENSIONS
const_iv(DEVICE_EXTENSIONS)
#endif
#ifdef CL_DEVICE_PLATFORM
const_iv(DEVICE_PLATFORM)
#endif
#ifdef CL_DEVICE_DOUBLE_FP_CONFIG
const_iv(DEVICE_DOUBLE_FP_CONFIG)
#endif
#ifdef CL_DEVICE_PREFERRED_VECTOR_WIDTH_HALF
const_iv(DEVICE_PREFERRED_VECTOR_WIDTH_HALF)
#endif
#ifdef CL_DEVICE_HOST_UNIFIED_MEMORY
const_iv(DEVICE_HOST_UNIFIED_MEMORY)
#endif
#ifdef CL_DEVICE_NATIVE_VECTOR_WIDTH_CHAR
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_CHAR)
#endif
#ifdef CL_DEVICE_NATIVE_VECTOR_WIDTH_SHORT
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_SHORT)
#endif
#ifdef CL_DEVICE_NATIVE_VECTOR_WIDTH_INT
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_INT)
#endif
#ifdef CL_DEVICE_NATIVE_VECTOR_WIDTH_LONG
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_LONG)
#endif
#ifdef CL_DEVICE_NATIVE_VECTOR_WIDTH_FLOAT
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_FLOAT)
#endif
#ifdef CL_DEVICE_NATIVE_VECTOR_WIDTH_DOUBLE
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_DOUBLE)
#endif
#ifdef CL_DEVICE_NATIVE_VECTOR_WIDTH_HALF
const_iv(DEVICE_NATIVE_VECTOR_WIDTH_HALF)
#endif
#ifdef CL_DEVICE_OPENCL_C_VERSION
const_iv(DEVICE_OPENCL_C_VERSION)
#endif
#ifdef CL_DEVICE_LINKER_AVAILABLE
const_iv(DEVICE_LINKER_AVAILABLE)
#endif
#ifdef CL_DEVICE_BUILT_IN_KERNELS
const_iv(DEVICE_BUILT_IN_KERNELS)
#endif
#ifdef CL_DEVICE_IMAGE_MAX_BUFFER_SIZE
const_iv(DEVICE_IMAGE_MAX_BUFFER_SIZE)
#endif
#ifdef CL_DEVICE_IMAGE_MAX_ARRAY_SIZE
const_iv(DEVICE_IMAGE_MAX_ARRAY_SIZE)
#endif
#ifdef CL_DEVICE_PARENT_DEVICE
const_iv(DEVICE_PARENT_DEVICE)
#endif
#ifdef CL_DEVICE_PARTITION_MAX_SUB_DEVICES
const_iv(DEVICE_PARTITION_MAX_SUB_DEVICES)
#endif
#ifdef CL_DEVICE_PARTITION_PROPERTIES
const_iv(DEVICE_PARTITION_PROPERTIES)
#endif
#ifdef CL_DEVICE_PARTITION_AFFINITY_DOMAIN
const_iv(DEVICE_PARTITION_AFFINITY_DOMAIN)
#endif
#ifdef CL_DEVICE_PARTITION_TYPE
const_iv(DEVICE_PARTITION_TYPE)
#endif
#ifdef CL_DEVICE_REFERENCE_COUNT
const_iv(DEVICE_REFERENCE_COUNT)
#endif
#ifdef CL_DEVICE_PREFERRED_INTEROP_USER_SYNC
const_iv(DEVICE_PREFERRED_INTEROP_USER_SYNC)
#endif
#ifdef CL_DEVICE_PRINTF_BUFFER_SIZE
const_iv(DEVICE_PRINTF_BUFFER_SIZE)
#endif
#ifdef CL_FP_DENORM
const_iv(FP_DENORM)
#endif
#ifdef CL_FP_INF_NAN
const_iv(FP_INF_NAN)
#endif
#ifdef CL_FP_ROUND_TO_NEAREST
const_iv(FP_ROUND_TO_NEAREST)
#endif
#ifdef CL_FP_ROUND_TO_ZERO
const_iv(FP_ROUND_TO_ZERO)
#endif
#ifdef CL_FP_ROUND_TO_INF
const_iv(FP_ROUND_TO_INF)
#endif
#ifdef CL_FP_FMA
const_iv(FP_FMA)
#endif
#ifdef CL_FP_SOFT_FLOAT
const_iv(FP_SOFT_FLOAT)
#endif
#ifdef CL_FP_CORRECTLY_ROUNDED_DIVIDE_SQRT
const_iv(FP_CORRECTLY_ROUNDED_DIVIDE_SQRT)
#endif
#ifdef CL_NONE
const_iv(NONE)
#endif
#ifdef CL_READ_ONLY_CACHE
const_iv(READ_ONLY_CACHE)
#endif
#ifdef CL_READ_WRITE_CACHE
const_iv(READ_WRITE_CACHE)
#endif
#ifdef CL_LOCAL
const_iv(LOCAL)
#endif
#ifdef CL_GLOBAL
const_iv(GLOBAL)
#endif
#ifdef CL_EXEC_KERNEL
const_iv(EXEC_KERNEL)
#endif
#ifdef CL_EXEC_NATIVE_KERNEL
const_iv(EXEC_NATIVE_KERNEL)
#endif
#ifdef CL_QUEUE_OUT_OF_ORDER_EXEC_MODE_ENABLE
const_iv(QUEUE_OUT_OF_ORDER_EXEC_MODE_ENABLE)
#endif
#ifdef CL_QUEUE_PROFILING_ENABLE
const_iv(QUEUE_PROFILING_ENABLE)
#endif
#ifdef CL_CONTEXT_REFERENCE_COUNT
const_iv(CONTEXT_REFERENCE_COUNT)
#endif
#ifdef CL_CONTEXT_DEVICES
const_iv(CONTEXT_DEVICES)
#endif
#ifdef CL_CONTEXT_PROPERTIES
const_iv(CONTEXT_PROPERTIES)
#endif
#ifdef CL_CONTEXT_NUM_DEVICES
const_iv(CONTEXT_NUM_DEVICES)
#endif
#ifdef CL_CONTEXT_PLATFORM
const_iv(CONTEXT_PLATFORM)
#endif
#ifdef CL_CONTEXT_INTEROP_USER_SYNC
const_iv(CONTEXT_INTEROP_USER_SYNC)
#endif
#ifdef CL_DEVICE_PARTITION_EQUALLY
const_iv(DEVICE_PARTITION_EQUALLY)
#endif
#ifdef CL_DEVICE_PARTITION_BY_COUNTS
const_iv(DEVICE_PARTITION_BY_COUNTS)
#endif
#ifdef CL_DEVICE_PARTITION_BY_COUNTS_LIST_END
const_iv(DEVICE_PARTITION_BY_COUNTS_LIST_END)
#endif
#ifdef CL_DEVICE_PARTITION_BY_AFFINITY_DOMAIN
const_iv(DEVICE_PARTITION_BY_AFFINITY_DOMAIN)
#endif
#ifdef CL_DEVICE_AFFINITY_DOMAIN_NUMA
const_iv(DEVICE_AFFINITY_DOMAIN_NUMA)
#endif
#ifdef CL_DEVICE_AFFINITY_DOMAIN_L4_CACHE
const_iv(DEVICE_AFFINITY_DOMAIN_L4_CACHE)
#endif
#ifdef CL_DEVICE_AFFINITY_DOMAIN_L3_CACHE
const_iv(DEVICE_AFFINITY_DOMAIN_L3_CACHE)
#endif
#ifdef CL_DEVICE_AFFINITY_DOMAIN_L2_CACHE
const_iv(DEVICE_AFFINITY_DOMAIN_L2_CACHE)
#endif
#ifdef CL_DEVICE_AFFINITY_DOMAIN_L1_CACHE
const_iv(DEVICE_AFFINITY_DOMAIN_L1_CACHE)
#endif
#ifdef CL_DEVICE_AFFINITY_DOMAIN_NEXT_PARTITIONABLE
const_iv(DEVICE_AFFINITY_DOMAIN_NEXT_PARTITIONABLE)
#endif
#ifdef CL_QUEUE_CONTEXT
const_iv(QUEUE_CONTEXT)
#endif
#ifdef CL_QUEUE_DEVICE
const_iv(QUEUE_DEVICE)
#endif
#ifdef CL_QUEUE_REFERENCE_COUNT
const_iv(QUEUE_REFERENCE_COUNT)
#endif
#ifdef CL_QUEUE_PROPERTIES
const_iv(QUEUE_PROPERTIES)
#endif
#ifdef CL_MEM_READ_WRITE
const_iv(MEM_READ_WRITE)
#endif
#ifdef CL_MEM_WRITE_ONLY
const_iv(MEM_WRITE_ONLY)
#endif
#ifdef CL_MEM_READ_ONLY
const_iv(MEM_READ_ONLY)
#endif
#ifdef CL_MEM_USE_HOST_PTR
const_iv(MEM_USE_HOST_PTR)
#endif
#ifdef CL_MEM_ALLOC_HOST_PTR
const_iv(MEM_ALLOC_HOST_PTR)
#endif
#ifdef CL_MEM_COPY_HOST_PTR
const_iv(MEM_COPY_HOST_PTR)
#endif
#ifdef CL_MEM_HOST_WRITE_ONLY
const_iv(MEM_HOST_WRITE_ONLY)
#endif
#ifdef CL_MEM_HOST_READ_ONLY
const_iv(MEM_HOST_READ_ONLY)
#endif
#ifdef CL_MEM_HOST_NO_ACCESS
const_iv(MEM_HOST_NO_ACCESS)
#endif
#ifdef CL_MIGRATE_MEM_OBJECT_HOST
const_iv(MIGRATE_MEM_OBJECT_HOST)
#endif
#ifdef CL_MIGRATE_MEM_OBJECT_CONTENT_UNDEFINED
const_iv(MIGRATE_MEM_OBJECT_CONTENT_UNDEFINED)
#endif
#ifdef CL_R
const_iv(R)
#endif
#ifdef CL_A
const_iv(A)
#endif
#ifdef CL_RG
const_iv(RG)
#endif
#ifdef CL_RA
const_iv(RA)
#endif
#ifdef CL_RGB
const_iv(RGB)
#endif
#ifdef CL_RGBA
const_iv(RGBA)
#endif
#ifdef CL_BGRA
const_iv(BGRA)
#endif
#ifdef CL_ARGB
const_iv(ARGB)
#endif
#ifdef CL_INTENSITY
const_iv(INTENSITY)
#endif
#ifdef CL_LUMINANCE
const_iv(LUMINANCE)
#endif
#ifdef CL_Rx
const_iv(Rx)
#endif
#ifdef CL_RGx
const_iv(RGx)
#endif
#ifdef CL_RGBx
const_iv(RGBx)
#endif
#ifdef CL_SNORM_INT8
const_iv(SNORM_INT8)
#endif
#ifdef CL_SNORM_INT16
const_iv(SNORM_INT16)
#endif
#ifdef CL_UNORM_INT8
const_iv(UNORM_INT8)
#endif
#ifdef CL_UNORM_INT16
const_iv(UNORM_INT16)
#endif
#ifdef CL_UNORM_SHORT_565
const_iv(UNORM_SHORT_565)
#endif
#ifdef CL_UNORM_SHORT_555
const_iv(UNORM_SHORT_555)
#endif
#ifdef CL_UNORM_INT_101010
const_iv(UNORM_INT_101010)
#endif
#ifdef CL_SIGNED_INT8
const_iv(SIGNED_INT8)
#endif
#ifdef CL_SIGNED_INT16
const_iv(SIGNED_INT16)
#endif
#ifdef CL_SIGNED_INT32
const_iv(SIGNED_INT32)
#endif
#ifdef CL_UNSIGNED_INT8
const_iv(UNSIGNED_INT8)
#endif
#ifdef CL_UNSIGNED_INT16
const_iv(UNSIGNED_INT16)
#endif
#ifdef CL_UNSIGNED_INT32
const_iv(UNSIGNED_INT32)
#endif
#ifdef CL_HALF_FLOAT
const_iv(HALF_FLOAT)
#endif
#ifdef CL_FLOAT
const_iv(FLOAT)
#endif
#ifdef CL_MEM_OBJECT_BUFFER
const_iv(MEM_OBJECT_BUFFER)
#endif
#ifdef CL_MEM_OBJECT_IMAGE2D
const_iv(MEM_OBJECT_IMAGE2D)
#endif
#ifdef CL_MEM_OBJECT_IMAGE3D
const_iv(MEM_OBJECT_IMAGE3D)
#endif
#ifdef CL_MEM_OBJECT_IMAGE2D_ARRAY
const_iv(MEM_OBJECT_IMAGE2D_ARRAY)
#endif
#ifdef CL_MEM_OBJECT_IMAGE1D
const_iv(MEM_OBJECT_IMAGE1D)
#endif
#ifdef CL_MEM_OBJECT_IMAGE1D_ARRAY
const_iv(MEM_OBJECT_IMAGE1D_ARRAY)
#endif
#ifdef CL_MEM_OBJECT_IMAGE1D_BUFFER
const_iv(MEM_OBJECT_IMAGE1D_BUFFER)
#endif
#ifdef CL_MEM_TYPE
const_iv(MEM_TYPE)
#endif
#ifdef CL_MEM_FLAGS
const_iv(MEM_FLAGS)
#endif
#ifdef CL_MEM_SIZE
const_iv(MEM_SIZE)
#endif
#ifdef CL_MEM_HOST_PTR
const_iv(MEM_HOST_PTR)
#endif
#ifdef CL_MEM_MAP_COUNT
const_iv(MEM_MAP_COUNT)
#endif
#ifdef CL_MEM_REFERENCE_COUNT
const_iv(MEM_REFERENCE_COUNT)
#endif
#ifdef CL_MEM_CONTEXT
const_iv(MEM_CONTEXT)
#endif
#ifdef CL_MEM_ASSOCIATED_MEMOBJECT
const_iv(MEM_ASSOCIATED_MEMOBJECT)
#endif
#ifdef CL_MEM_OFFSET
const_iv(MEM_OFFSET)
#endif
#ifdef CL_IMAGE_FORMAT
const_iv(IMAGE_FORMAT)
#endif
#ifdef CL_IMAGE_ELEMENT_SIZE
const_iv(IMAGE_ELEMENT_SIZE)
#endif
#ifdef CL_IMAGE_ROW_PITCH
const_iv(IMAGE_ROW_PITCH)
#endif
#ifdef CL_IMAGE_SLICE_PITCH
const_iv(IMAGE_SLICE_PITCH)
#endif
#ifdef CL_IMAGE_WIDTH
const_iv(IMAGE_WIDTH)
#endif
#ifdef CL_IMAGE_HEIGHT
const_iv(IMAGE_HEIGHT)
#endif
#ifdef CL_IMAGE_DEPTH
const_iv(IMAGE_DEPTH)
#endif
#ifdef CL_IMAGE_ARRAY_SIZE
const_iv(IMAGE_ARRAY_SIZE)
#endif
#ifdef CL_IMAGE_BUFFER
const_iv(IMAGE_BUFFER)
#endif
#ifdef CL_IMAGE_NUM_MIP_LEVELS
const_iv(IMAGE_NUM_MIP_LEVELS)
#endif
#ifdef CL_IMAGE_NUM_SAMPLES
const_iv(IMAGE_NUM_SAMPLES)
#endif
#ifdef CL_ADDRESS_NONE
const_iv(ADDRESS_NONE)
#endif
#ifdef CL_ADDRESS_CLAMP_TO_EDGE
const_iv(ADDRESS_CLAMP_TO_EDGE)
#endif
#ifdef CL_ADDRESS_CLAMP
const_iv(ADDRESS_CLAMP)
#endif
#ifdef CL_ADDRESS_REPEAT
const_iv(ADDRESS_REPEAT)
#endif
#ifdef CL_ADDRESS_MIRRORED_REPEAT
const_iv(ADDRESS_MIRRORED_REPEAT)
#endif
#ifdef CL_FILTER_NEAREST
const_iv(FILTER_NEAREST)
#endif
#ifdef CL_FILTER_LINEAR
const_iv(FILTER_LINEAR)
#endif
#ifdef CL_SAMPLER_REFERENCE_COUNT
const_iv(SAMPLER_REFERENCE_COUNT)
#endif
#ifdef CL_SAMPLER_CONTEXT
const_iv(SAMPLER_CONTEXT)
#endif
#ifdef CL_SAMPLER_NORMALIZED_COORDS
const_iv(SAMPLER_NORMALIZED_COORDS)
#endif
#ifdef CL_SAMPLER_ADDRESSING_MODE
const_iv(SAMPLER_ADDRESSING_MODE)
#endif
#ifdef CL_SAMPLER_FILTER_MODE
const_iv(SAMPLER_FILTER_MODE)
#endif
#ifdef CL_MAP_READ
const_iv(MAP_READ)
#endif
#ifdef CL_MAP_WRITE
const_iv(MAP_WRITE)
#endif
#ifdef CL_MAP_WRITE_INVALIDATE_REGION
const_iv(MAP_WRITE_INVALIDATE_REGION)
#endif
#ifdef CL_PROGRAM_REFERENCE_COUNT
const_iv(PROGRAM_REFERENCE_COUNT)
#endif
#ifdef CL_PROGRAM_CONTEXT
const_iv(PROGRAM_CONTEXT)
#endif
#ifdef CL_PROGRAM_NUM_DEVICES
const_iv(PROGRAM_NUM_DEVICES)
#endif
#ifdef CL_PROGRAM_DEVICES
const_iv(PROGRAM_DEVICES)
#endif
#ifdef CL_PROGRAM_SOURCE
const_iv(PROGRAM_SOURCE)
#endif
#ifdef CL_PROGRAM_BINARY_SIZES
const_iv(PROGRAM_BINARY_SIZES)
#endif
#ifdef CL_PROGRAM_BINARIES
const_iv(PROGRAM_BINARIES)
#endif
#ifdef CL_PROGRAM_NUM_KERNELS
const_iv(PROGRAM_NUM_KERNELS)
#endif
#ifdef CL_PROGRAM_KERNEL_NAMES
const_iv(PROGRAM_KERNEL_NAMES)
#endif
#ifdef CL_PROGRAM_BUILD_STATUS
const_iv(PROGRAM_BUILD_STATUS)
#endif
#ifdef CL_PROGRAM_BUILD_OPTIONS
const_iv(PROGRAM_BUILD_OPTIONS)
#endif
#ifdef CL_PROGRAM_BUILD_LOG
const_iv(PROGRAM_BUILD_LOG)
#endif
#ifdef CL_PROGRAM_BINARY_TYPE
const_iv(PROGRAM_BINARY_TYPE)
#endif
#ifdef CL_PROGRAM_BINARY_TYPE_NONE
const_iv(PROGRAM_BINARY_TYPE_NONE)
#endif
#ifdef CL_PROGRAM_BINARY_TYPE_COMPILED_OBJECT
const_iv(PROGRAM_BINARY_TYPE_COMPILED_OBJECT)
#endif
#ifdef CL_PROGRAM_BINARY_TYPE_LIBRARY
const_iv(PROGRAM_BINARY_TYPE_LIBRARY)
#endif
#ifdef CL_PROGRAM_BINARY_TYPE_EXECUTABLE
const_iv(PROGRAM_BINARY_TYPE_EXECUTABLE)
#endif
#ifdef CL_BUILD_SUCCESS
const_iv(BUILD_SUCCESS)
#endif
#ifdef CL_BUILD_NONE
const_iv(BUILD_NONE)
#endif
#ifdef CL_BUILD_ERROR
const_iv(BUILD_ERROR)
#endif
#ifdef CL_BUILD_IN_PROGRESS
const_iv(BUILD_IN_PROGRESS)
#endif
#ifdef CL_KERNEL_FUNCTION_NAME
const_iv(KERNEL_FUNCTION_NAME)
#endif
#ifdef CL_KERNEL_NUM_ARGS
const_iv(KERNEL_NUM_ARGS)
#endif
#ifdef CL_KERNEL_REFERENCE_COUNT
const_iv(KERNEL_REFERENCE_COUNT)
#endif
#ifdef CL_KERNEL_CONTEXT
const_iv(KERNEL_CONTEXT)
#endif
#ifdef CL_KERNEL_PROGRAM
const_iv(KERNEL_PROGRAM)
#endif
#ifdef CL_KERNEL_ATTRIBUTES
const_iv(KERNEL_ATTRIBUTES)
#endif
#ifdef CL_KERNEL_ARG_ADDRESS_QUALIFIER
const_iv(KERNEL_ARG_ADDRESS_QUALIFIER)
#endif
#ifdef CL_KERNEL_ARG_ACCESS_QUALIFIER
const_iv(KERNEL_ARG_ACCESS_QUALIFIER)
#endif
#ifdef CL_KERNEL_ARG_TYPE_NAME
const_iv(KERNEL_ARG_TYPE_NAME)
#endif
#ifdef CL_KERNEL_ARG_TYPE_QUALIFIER
const_iv(KERNEL_ARG_TYPE_QUALIFIER)
#endif
#ifdef CL_KERNEL_ARG_NAME
const_iv(KERNEL_ARG_NAME)
#endif
#ifdef CL_KERNEL_ARG_ADDRESS_GLOBAL
const_iv(KERNEL_ARG_ADDRESS_GLOBAL)
#endif
#ifdef CL_KERNEL_ARG_ADDRESS_LOCAL
const_iv(KERNEL_ARG_ADDRESS_LOCAL)
#endif
#ifdef CL_KERNEL_ARG_ADDRESS_CONSTANT
const_iv(KERNEL_ARG_ADDRESS_CONSTANT)
#endif
#ifdef CL_KERNEL_ARG_ADDRESS_PRIVATE
const_iv(KERNEL_ARG_ADDRESS_PRIVATE)
#endif
#ifdef CL_KERNEL_ARG_ACCESS_READ_ONLY
const_iv(KERNEL_ARG_ACCESS_READ_ONLY)
#endif
#ifdef CL_KERNEL_ARG_ACCESS_WRITE_ONLY
const_iv(KERNEL_ARG_ACCESS_WRITE_ONLY)
#endif
#ifdef CL_KERNEL_ARG_ACCESS_READ_WRITE
const_iv(KERNEL_ARG_ACCESS_READ_WRITE)
#endif
#ifdef CL_KERNEL_ARG_ACCESS_NONE
const_iv(KERNEL_ARG_ACCESS_NONE)
#endif
#ifdef CL_KERNEL_ARG_TYPE_NONE
const_iv(KERNEL_ARG_TYPE_NONE)
#endif
#ifdef CL_KERNEL_ARG_TYPE_CONST
const_iv(KERNEL_ARG_TYPE_CONST)
#endif
#ifdef CL_KERNEL_ARG_TYPE_RESTRICT
const_iv(KERNEL_ARG_TYPE_RESTRICT)
#endif
#ifdef CL_KERNEL_ARG_TYPE_VOLATILE
const_iv(KERNEL_ARG_TYPE_VOLATILE)
#endif
#ifdef CL_KERNEL_WORK_GROUP_SIZE
const_iv(KERNEL_WORK_GROUP_SIZE)
#endif
#ifdef CL_KERNEL_COMPILE_WORK_GROUP_SIZE
const_iv(KERNEL_COMPILE_WORK_GROUP_SIZE)
#endif
#ifdef CL_KERNEL_LOCAL_MEM_SIZE
const_iv(KERNEL_LOCAL_MEM_SIZE)
#endif
#ifdef CL_KERNEL_PREFERRED_WORK_GROUP_SIZE_MULTIPLE
const_iv(KERNEL_PREFERRED_WORK_GROUP_SIZE_MULTIPLE)
#endif
#ifdef CL_KERNEL_PRIVATE_MEM_SIZE
const_iv(KERNEL_PRIVATE_MEM_SIZE)
#endif
#ifdef CL_KERNEL_GLOBAL_WORK_SIZE
const_iv(KERNEL_GLOBAL_WORK_SIZE)
#endif
#ifdef CL_EVENT_COMMAND_QUEUE
const_iv(EVENT_COMMAND_QUEUE)
#endif
#ifdef CL_EVENT_COMMAND_TYPE
const_iv(EVENT_COMMAND_TYPE)
#endif
#ifdef CL_EVENT_REFERENCE_COUNT
const_iv(EVENT_REFERENCE_COUNT)
#endif
#ifdef CL_EVENT_COMMAND_EXECUTION_STATUS
const_iv(EVENT_COMMAND_EXECUTION_STATUS)
#endif
#ifdef CL_EVENT_CONTEXT
const_iv(EVENT_CONTEXT)
#endif
#ifdef CL_COMMAND_NDRANGE_KERNEL
const_iv(COMMAND_NDRANGE_KERNEL)
#endif
#ifdef CL_COMMAND_TASK
const_iv(COMMAND_TASK)
#endif
#ifdef CL_COMMAND_NATIVE_KERNEL
const_iv(COMMAND_NATIVE_KERNEL)
#endif
#ifdef CL_COMMAND_READ_BUFFER
const_iv(COMMAND_READ_BUFFER)
#endif
#ifdef CL_COMMAND_WRITE_BUFFER
const_iv(COMMAND_WRITE_BUFFER)
#endif
#ifdef CL_COMMAND_COPY_BUFFER
const_iv(COMMAND_COPY_BUFFER)
#endif
#ifdef CL_COMMAND_READ_IMAGE
const_iv(COMMAND_READ_IMAGE)
#endif
#ifdef CL_COMMAND_WRITE_IMAGE
const_iv(COMMAND_WRITE_IMAGE)
#endif
#ifdef CL_COMMAND_COPY_IMAGE
const_iv(COMMAND_COPY_IMAGE)
#endif
#ifdef CL_COMMAND_COPY_IMAGE_TO_BUFFER
const_iv(COMMAND_COPY_IMAGE_TO_BUFFER)
#endif
#ifdef CL_COMMAND_COPY_BUFFER_TO_IMAGE
const_iv(COMMAND_COPY_BUFFER_TO_IMAGE)
#endif
#ifdef CL_COMMAND_MAP_BUFFER
const_iv(COMMAND_MAP_BUFFER)
#endif
#ifdef CL_COMMAND_MAP_IMAGE
const_iv(COMMAND_MAP_IMAGE)
#endif
#ifdef CL_COMMAND_UNMAP_MEM_OBJECT
const_iv(COMMAND_UNMAP_MEM_OBJECT)
#endif
#ifdef CL_COMMAND_MARKER
const_iv(COMMAND_MARKER)
#endif
#ifdef CL_COMMAND_ACQUIRE_GL_OBJECTS
const_iv(COMMAND_ACQUIRE_GL_OBJECTS)
#endif
#ifdef CL_COMMAND_RELEASE_GL_OBJECTS
const_iv(COMMAND_RELEASE_GL_OBJECTS)
#endif
#ifdef CL_COMMAND_READ_BUFFER_RECT
const_iv(COMMAND_READ_BUFFER_RECT)
#endif
#ifdef CL_COMMAND_WRITE_BUFFER_RECT
const_iv(COMMAND_WRITE_BUFFER_RECT)
#endif
#ifdef CL_COMMAND_COPY_BUFFER_RECT
const_iv(COMMAND_COPY_BUFFER_RECT)
#endif
#ifdef CL_COMMAND_USER
const_iv(COMMAND_USER)
#endif
#ifdef CL_COMMAND_BARRIER
const_iv(COMMAND_BARRIER)
#endif
#ifdef CL_COMMAND_MIGRATE_MEM_OBJECTS
const_iv(COMMAND_MIGRATE_MEM_OBJECTS)
#endif
#ifdef CL_COMMAND_FILL_BUFFER
const_iv(COMMAND_FILL_BUFFER)
#endif
#ifdef CL_COMMAND_FILL_IMAGE
const_iv(COMMAND_FILL_IMAGE)
#endif
#ifdef CL_COMPLETE
const_iv(COMPLETE)
#endif
#ifdef CL_RUNNING
const_iv(RUNNING)
#endif
#ifdef CL_SUBMITTED
const_iv(SUBMITTED)
#endif
#ifdef CL_QUEUED
const_iv(QUEUED)
#endif
#ifdef CL_BUFFER_CREATE_TYPE_REGION
const_iv(BUFFER_CREATE_TYPE_REGION)
#endif
#ifdef CL_PROFILING_COMMAND_QUEUED
const_iv(PROFILING_COMMAND_QUEUED)
#endif
#ifdef CL_PROFILING_COMMAND_SUBMIT
const_iv(PROFILING_COMMAND_SUBMIT)
#endif
#ifdef CL_PROFILING_COMMAND_START
const_iv(PROFILING_COMMAND_START)
#endif
#ifdef CL_PROFILING_COMMAND_END
const_iv(PROFILING_COMMAND_END)
#endif
#ifdef CL_DEVICE_DOUBLE_FP_CONFIG
const_iv(DEVICE_DOUBLE_FP_CONFIG)
#endif
#ifdef CL_DEVICE_HALF_FP_CONFIG
const_iv(DEVICE_HALF_FP_CONFIG)
#endif
#ifdef CL_PLATFORM_ICD_SUFFIX_KHR
const_iv(PLATFORM_ICD_SUFFIX_KHR)
#endif
#ifdef CL_PLATFORM_NOT_FOUND_KHR
const_iv(PLATFORM_NOT_FOUND_KHR)
#endif
#ifdef CL_DEVICE_COMPUTE_CAPABILITY_MAJOR_NV
const_iv(DEVICE_COMPUTE_CAPABILITY_MAJOR_NV)
#endif
#ifdef CL_DEVICE_COMPUTE_CAPABILITY_MINOR_NV
const_iv(DEVICE_COMPUTE_CAPABILITY_MINOR_NV)
#endif
#ifdef CL_DEVICE_REGISTERS_PER_BLOCK_NV
const_iv(DEVICE_REGISTERS_PER_BLOCK_NV)
#endif
#ifdef CL_DEVICE_WARP_SIZE_NV
const_iv(DEVICE_WARP_SIZE_NV)
#endif
#ifdef CL_DEVICE_GPU_OVERLAP_NV
const_iv(DEVICE_GPU_OVERLAP_NV)
#endif
#ifdef CL_DEVICE_KERNEL_EXEC_TIMEOUT_NV
const_iv(DEVICE_KERNEL_EXEC_TIMEOUT_NV)
#endif
#ifdef CL_DEVICE_INTEGRATED_MEMORY_NV
const_iv(DEVICE_INTEGRATED_MEMORY_NV)
#endif
#ifdef CL_DEVICE_PROFILING_TIMER_OFFSET_AMD
const_iv(DEVICE_PROFILING_TIMER_OFFSET_AMD)
#endif
#ifdef CL_GL_OBJECT_BUFFER
const_iv(GL_OBJECT_BUFFER)
#endif
#ifdef CL_GL_OBJECT_TEXTURE2D
const_iv(GL_OBJECT_TEXTURE2D)
#endif
#ifdef CL_GL_OBJECT_TEXTURE3D
const_iv(GL_OBJECT_TEXTURE3D)
#endif
#ifdef CL_GL_OBJECT_RENDERBUFFER
const_iv(GL_OBJECT_RENDERBUFFER)
#endif
#ifdef CL_GL_OBJECT_TEXTURE2D_ARRAY
const_iv(GL_OBJECT_TEXTURE2D_ARRAY)
#endif
#ifdef CL_GL_OBJECT_TEXTURE1D
const_iv(GL_OBJECT_TEXTURE1D)
#endif
#ifdef CL_GL_OBJECT_TEXTURE1D_ARRAY
const_iv(GL_OBJECT_TEXTURE1D_ARRAY)
#endif
#ifdef CL_GL_OBJECT_TEXTURE_BUFFER
const_iv(GL_OBJECT_TEXTURE_BUFFER)
#endif
#ifdef CL_GL_TEXTURE_TARGET
const_iv(GL_TEXTURE_TARGET)
#endif
#ifdef CL_GL_MIPMAP_LEVEL
const_iv(GL_MIPMAP_LEVEL)
#endif
#ifdef CL_INVALID_GL_SHAREGROUP_REFERENCE_KHR
const_iv(INVALID_GL_SHAREGROUP_REFERENCE_KHR)
#endif
#ifdef CL_CURRENT_DEVICE_FOR_GL_CONTEXT_KHR
const_iv(CURRENT_DEVICE_FOR_GL_CONTEXT_KHR)
#endif
#ifdef CL_DEVICES_FOR_GL_CONTEXT_KHR
const_iv(DEVICES_FOR_GL_CONTEXT_KHR)
#endif
#ifdef CL_GL_CONTEXT_KHR
const_iv(GL_CONTEXT_KHR)
#endif
#ifdef CL_EGL_DISPLAY_KHR
const_iv(EGL_DISPLAY_KHR)
#endif
#ifdef CL_GLX_DISPLAY_KHR
const_iv(GLX_DISPLAY_KHR)
#endif
#ifdef CL_WGL_HDC_KHR
const_iv(WGL_HDC_KHR)
#endif
#ifdef CL_CGL_SHAREGROUP_KHR
const_iv(CGL_SHAREGROUP_KHR)
#endif
#ifdef CL_COMMAND_GL_FENCE_SYNC_OBJECT_KHR
const_iv(COMMAND_GL_FENCE_SYNC_OBJECT_KHR)
#endif
#ifdef CL_INVALID_D3D10_DEVICE_KHR
const_iv(INVALID_D3D10_DEVICE_KHR)
#endif
#ifdef CL_INVALID_D3D10_RESOURCE_KHR
const_iv(INVALID_D3D10_RESOURCE_KHR)
#endif
#ifdef CL_D3D10_RESOURCE_ALREADY_ACQUIRED_KHR
const_iv(D3D10_RESOURCE_ALREADY_ACQUIRED_KHR)
#endif
#ifdef CL_D3D10_RESOURCE_NOT_ACQUIRED_KHR
const_iv(D3D10_RESOURCE_NOT_ACQUIRED_KHR)
#endif
#ifdef CL_D3D10_DEVICE_KHR
const_iv(D3D10_DEVICE_KHR)
#endif
#ifdef CL_D3D10_DXGI_ADAPTER_KHR
const_iv(D3D10_DXGI_ADAPTER_KHR)
#endif
#ifdef CL_PREFERRED_DEVICES_FOR_D3D10_KHR
const_iv(PREFERRED_DEVICES_FOR_D3D10_KHR)
#endif
#ifdef CL_ALL_DEVICES_FOR_D3D10_KHR
const_iv(ALL_DEVICES_FOR_D3D10_KHR)
#endif
#ifdef CL_CONTEXT_D3D10_DEVICE_KHR
const_iv(CONTEXT_D3D10_DEVICE_KHR)
#endif
#ifdef CL_CONTEXT_D3D10_PREFER_SHARED_RESOURCES_KHR
const_iv(CONTEXT_D3D10_PREFER_SHARED_RESOURCES_KHR)
#endif
#ifdef CL_MEM_D3D10_RESOURCE_KHR
const_iv(MEM_D3D10_RESOURCE_KHR)
#endif
#ifdef CL_IMAGE_D3D10_SUBRESOURCE_KHR
const_iv(IMAGE_D3D10_SUBRESOURCE_KHR)
#endif
#ifdef CL_COMMAND_ACQUIRE_D3D10_OBJECTS_KHR
const_iv(COMMAND_ACQUIRE_D3D10_OBJECTS_KHR)
#endif
#ifdef CL_COMMAND_RELEASE_D3D10_OBJECTS_KHR
const_iv(COMMAND_RELEASE_D3D10_OBJECTS_KHR)
#endif
